@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2008 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,7 +27,7 @@
 /**
  * HTML mail class
  *
- * $Id: class.t3lib_htmlmail.php 4487 2008-11-25 09:16:07Z steffenk $
+ * $Id: class.t3lib_htmlmail.php 6108 2009-10-07 09:51:30Z ohader $
  *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
  */
@@ -184,6 +184,7 @@ class t3lib_htmlmail {
 		// Headerinfo:
 	var $recipient		= '';
 	var $recipient_copy	= '';	// This recipient (or list of...) will also receive the mail. Regard it as a copy.
+	var $recipient_blindcopy = ''; // This recipient (or list of...) will also receive the mail as a blind copy. Regard it as a copy.
 	var $subject		= '';
 	var $from_email		= '';
 	var $from_name		= '';
@@ -482,6 +483,17 @@ class t3lib_htmlmail {
 				$this->add_header('From: '.$this->from_email);
 			}
 		}
+
+			// Cc
+		if ($this->recipient_copy) {
+			$this->add_header('Cc: ' . $this->recipient_copy);
+		}
+
+			// Bcc
+		if ($this->recipient_blindcopy) {
+			$this->add_header('Bcc: ' . $this->recipient_blindcopy);
+		}
+
 			// Reply
 		if ($this->replyto_email) {
 			if ($this->replyto_name) {
@@ -923,14 +935,14 @@ class t3lib_htmlmail {
 		$attribRegex = $this->tag_regex(array('img','table','td','tr','body','iframe','script','input','embed'));
 
 			// split the document by the beginning of the above tags
-		$codepieces = split($attribRegex, $html_code);
+		$codepieces = preg_split($attribRegex, $html_code);
 		$len = strlen($codepieces[0]);
 		$pieces = count($codepieces);
 		$reg = array();
 		for ($i = 1; $i < $pieces; $i++) {
 			$tag = strtolower(strtok(substr($html_code,$len+1,10),' '));
 			$len += strlen($tag)+strlen($codepieces[$i])+2;
-			$dummy = eregi("[^>]*", $codepieces[$i], $reg);
+			$dummy = preg_match('/[^>]*/', $codepieces[$i], $reg);
 			$attributes = $this->get_tag_attributes($reg[0]);	// Fetches the attributes for the tag
 			$imageData = array();
 
@@ -954,10 +966,10 @@ class t3lib_htmlmail {
 			// Extracting stylesheets
 		$attribRegex = $this->tag_regex(array('link'));
 			// Split the document by the beginning of the above tags
-		$codepieces = split($attribRegex, $html_code);
+		$codepieces = preg_split($attribRegex, $html_code);
 		$pieces = count($codepieces);
 		for ($i = 1; $i < $pieces; $i++) {
-			$dummy = eregi("[^>]*", $codepieces[$i], $reg);
+			$dummy = preg_match('/[^>]*/', $codepieces[$i], $reg);
 				// fetches the attributes for the tag
 			$attributes = $this->get_tag_attributes($reg[0]);
 			$imageData = array();
@@ -977,13 +989,13 @@ class t3lib_htmlmail {
 		}
 
 			// fixes javascript rollovers
-		$codepieces = split(quotemeta(".src"), $html_code);
+		$codepieces = explode('.src', $html_code);
 		$pieces = count($codepieces);
-		$expr = "^[^".quotemeta("\"").quotemeta("'")."]*";
+		$expr = '/^[^'.quotemeta('"').quotemeta("'").']*/';
 		for($i = 1; $i < $pieces; $i++) {
 			$temp = $codepieces[$i];
-			$temp = trim(ereg_replace("=","",trim($temp)));
-			ereg($expr,substr($temp,1,strlen($temp)),$reg);
+			$temp = trim(str_replace('=','',trim($temp)));
+			preg_match($expr,substr($temp,1,strlen($temp)),$reg);
 			$imageData['ref'] = $reg[0];
 			$imageData['quotes'] = substr($temp,0,1);
 				// subst_str is the string to look for, when substituting lateron
@@ -1013,14 +1025,14 @@ class t3lib_htmlmail {
 	public function extractHyperLinks() {
 		$html_code = $this->theParts['html']['content'];
 		$attribRegex = $this->tag_regex(array('a','form','area'));
-		$codepieces = split($attribRegex, $html_code);	// Splits the document by the beginning of the above tags
+		$codepieces = preg_split($attribRegex, $html_code);	// Splits the document by the beginning of the above tags
 		$len = strlen($codepieces[0]);
 		$pieces = count($codepieces);
 		for($i = 1; $i < $pieces; $i++) {
 			$tag = strtolower(strtok(substr($html_code,$len+1,10)," "));
 			$len += strlen($tag) + strlen($codepieces[$i]) + 2;
 
-			$dummy = eregi("[^>]*", $codepieces[$i], $reg);
+			$dummy = preg_match('/[^>]*/', $codepieces[$i], $reg);
 				// Fetches the attributes for the tag
 			$attributes = $this->get_tag_attributes($reg[0]);
 			$hrefData = array();
@@ -1069,10 +1081,10 @@ class t3lib_htmlmail {
 		if (strpos(' '.$htmlCode,'<frame ')) {
 			$attribRegex = $this->tag_regex('frame');
 				// Splits the document by the beginning of the above tags
-			$codepieces = split($attribRegex, $htmlCode, 1000000);
+			$codepieces = preg_split($attribRegex, $htmlCode, 1000000);
 			$pieces = count($codepieces);
 			for($i = 1; $i < $pieces; $i++) {
-				$dummy = eregi("[^>]*", $codepieces[$i], $reg);
+				$dummy = preg_match('/[^>]*/', $codepieces[$i], $reg);
 					// Fetches the attributes for the tag
 				$attributes = $this->get_tag_attributes($reg[0]);
 				$frame = array();
@@ -1154,8 +1166,7 @@ class t3lib_htmlmail {
 			$len = strcspn($textpieces[$i],chr(32).chr(9).chr(13).chr(10));
 			if (trim(substr($textstr,-1)) == '' && $len) {
 				$lastChar = substr($textpieces[$i],$len-1,1);
-				if (!ereg("[A-Za-z0-9\/#]",$lastChar)) {
-					// Included "\/" 3/12
+				if (!preg_match('/[A-Za-z0-9\/#]/',$lastChar)) {
 					$len--;
 				}
 
@@ -1193,11 +1204,11 @@ class t3lib_htmlmail {
 
 		foreach($items as $key => $part) {
 			$sub = substr($part, 0, 200);
-			if (ereg("cid:part[^ \"']*",$sub,$reg)) {
+			if (preg_match('/cid:part[^ "\']*/',$sub,$reg)) {
 					// The position of the string
 				$thePos = strpos($part,$reg[0]);
 					// Finds the id of the media...
-				ereg("cid:part([^\.]*).*",$sub,$reg2);
+				preg_match('/cid:part([^\.]*).*/',$sub,$reg2);
 				$theSubStr = $this->theParts['html']['media'][intval($reg2[1])]['absRef'];
 				if ($thePos && $theSubStr) {
 					// ... and substitutes the javaScript rollover image with this instead
@@ -1357,7 +1368,7 @@ class t3lib_htmlmail {
 		$info = parse_url($ref);
 		if ($info['scheme']) {
 			return $ref;
-		} elseif (eregi("^/",$ref)) {
+		} elseif (preg_match('/^\//',$ref)) {
 			$addr = parse_url($this->theParts['html']['path']);
 			return  $addr['scheme'].'://'.$addr['host'].($addr['port']?':'.$addr['port']:'').$ref;
 		} else {
@@ -1375,7 +1386,7 @@ class t3lib_htmlmail {
 	 */
 	public function split_fileref($fileref) {
 		$info = array();
-		if (ereg("(.*/)(.*)$", $fileref, $reg)) {
+		if (preg_match('/(.*\/)(.*)$/', $fileref, $reg)) {
 			$info['path'] = $reg[1];
 			$info['file'] = $reg[2];
 		} else	{
@@ -1383,7 +1394,7 @@ class t3lib_htmlmail {
 			$info['file'] = $fileref;
 		}
 		$reg = '';
-		if (ereg("(.*)\.([^\.]*$)", $info['file'], $reg)) {
+		if (preg_match('/(.*)\.([^\.]*$)/', $info['file'], $reg)) {
 			$info['filebody'] = $reg[1];
 			$info['fileext'] = strtolower($reg[2]);
 			$info['realFileext'] = $reg[2];
@@ -1403,7 +1414,7 @@ class t3lib_htmlmail {
 	 */
 	public function extParseUrl($path) {
 		$res = parse_url($path);
-		ereg("(.*/)([^/]*)$", $res['path'], $reg);
+		preg_match('/(.*\/)([^\/]*)$/', $res['path'], $reg);
 		$res['filepath'] = $reg[1];
 		$res['filename'] = $reg[2];
 		return $res;
@@ -1418,13 +1429,13 @@ class t3lib_htmlmail {
 	 */
 	public function tag_regex($tags) {
 		$tags = (!is_array($tags) ? array($tags) : $tags);
-		$regexp = '';
+		$regexp = '/';
 		$c = count($tags);
 		foreach($tags as $tag) {
 			$c--;
 			$regexp .= '<' . sql_regcase($tag) . "[[:space:]]" . (($c) ? '|' : '');
 		}
-		return $regexp;
+		return $regexp . '/';
 	}
 
 
@@ -1438,13 +1449,13 @@ class t3lib_htmlmail {
 	 */
 	public function get_tag_attributes($tag) {
 		$attributes = array();
-		$tag = ltrim(eregi_replace ("^<[^ ]*","",trim($tag)));
+		$tag = ltrim(preg_replace('/^<[^ ]*/','',trim($tag)));
 		$tagLen = strlen($tag);
 		$safetyCounter = 100;
 			// Find attribute
 		while ($tag) {
 			$value = '';
-			$reg = split("[[:space:]=>]",$tag,2);
+			$reg = preg_split('/[[:space:]=>]/', $tag, 2);
 			$attrib = $reg[0];
 
 			$tag = ltrim(substr($tag,strlen($attrib),$tagLen));
@@ -1457,7 +1468,7 @@ class t3lib_htmlmail {
 					$value = $reg[0];
 				} else {
 						// No quotes around value
-					ereg("^([^[:space:]>]*)(.*)",$tag,$reg);
+					preg_match('/^([^[:space:]>]*)(.*)/',$tag,$reg);
 					$value = trim($reg[1]);
 					$tag = ltrim($reg[2]);
 					if (substr($tag,0,1) == '>') {
@@ -1503,4 +1514,5 @@ class t3lib_htmlmail {
 if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_htmlmail.php']) {
 	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['t3lib/class.t3lib_htmlmail.php']);
 }
+
 ?>
