@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2004 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,7 +27,7 @@
 /**
  * Contains class for creating a position map.
  *
- * $Id: class.t3lib_positionmap.php,v 1.11 2004/09/13 22:57:18 typo3 Exp $
+ * $Id: class.t3lib_positionmap.php 5175 2009-03-10 20:36:07Z ohader $
  * Revised for TYPO3 3.6 November/2003 by Kasper Skaarhoj
  * XHTML compliant (should be)
  *
@@ -53,13 +53,13 @@
  *
  *              SECTION: Content element positioning:
  *  404:     function printContentElementColumns($pid,$moveUid,$colPosList,$showHidden,$R_URI)
- *  440:     function printRecordMap($lines,$colPosArray)
- *  478:     function wrapColumnHeader($str,$vv)
- *  492:     function insertPositionIcon($row,$vv,$kk,$moveUid,$pid)
- *  509:     function onClickInsertRecord($row,$vv,$moveUid,$pid,$sys_lang=0)
- *  529:     function wrapRecordHeader($str,$row)
- *  539:     function getRecordHeader($row)
- *  552:     function wrapRecordTitle($str,$row)
+ *  442:     function printRecordMap($lines,$colPosArray)
+ *  480:     function wrapColumnHeader($str,$vv)
+ *  494:     function insertPositionIcon($row,$vv,$kk,$moveUid,$pid)
+ *  511:     function onClickInsertRecord($row,$vv,$moveUid,$pid,$sys_lang=0)
+ *  531:     function wrapRecordHeader($str,$row)
+ *  541:     function getRecordHeader($row)
+ *  554:     function wrapRecordTitle($str,$row)
  *
  * TOTAL FUNCTIONS: 17
  * (This index is automatically created/updated by the extension "extdeveval")
@@ -295,7 +295,7 @@ class t3lib_positionMap {
 
 		if ($TSconfigProp['overrideWithExtension'])	{
 			if (t3lib_extMgm::isLoaded($TSconfigProp['overrideWithExtension']))	{
-				$onclick = "document.location='".t3lib_extMgm::extRelPath($TSconfigProp['overrideWithExtension']).'mod1/index.php?cmd=crPage&positionPid='.$pid."';";
+				$onclick = "window.location.href='".t3lib_extMgm::extRelPath($TSconfigProp['overrideWithExtension']).'mod1/index.php?cmd=crPage&positionPid='.$pid."';";
 				return $onclick;
 			}
 		}
@@ -415,15 +415,19 @@ class t3lib_positionMap {
 								($showHidden ? '' : t3lib_BEfunc::BEenableFields('tt_content')).
 								' AND colPos='.intval($vv).
 								(strcmp($this->cur_sys_language,'') ? ' AND sys_language_uid='.intval($this->cur_sys_language) : '').
-								t3lib_BEfunc::deleteClause('tt_content'),
+								t3lib_BEfunc::deleteClause('tt_content').
+								t3lib_BEfunc::versioningPlaceholderClause('tt_content'),
 							'',
 							'sorting'
 						);
 			$lines[$kk]=array();
 			$lines[$kk][]=$this->insertPositionIcon('',$vv,$kk,$moveUid,$pid);
 			while($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res))		{
-				$lines[$kk][]=$this->wrapRecordHeader($this->getRecordHeader($row),$row);
-				$lines[$kk][]=$this->insertPositionIcon($row,$vv,$kk,$moveUid,$pid);
+				t3lib_BEfunc::workspaceOL('tt_content',$row);
+				if (is_array($row))	{
+					$lines[$kk][]=$this->wrapRecordHeader($this->getRecordHeader($row),$row);
+					$lines[$kk][]=$this->insertPositionIcon($row,$vv,$kk,$moveUid,$pid);
+				}
 			}
 			$GLOBALS['TYPO3_DB']->sql_free_result($res);
 		}
@@ -516,7 +520,7 @@ class t3lib_positionMap {
 //		$location.='&redirect='.rawurlencode($this->R_URI);		// returns to prev. page
 		$location.='&uPT=1&redirect='.rawurlencode(t3lib_div::getIndpEnv('REQUEST_URI'));		// This redraws screen
 
-		return 'document.location=\''.$location.'\';return false;';
+		return 'window.location.href=\''.$location.'\';return false;';
 	}
 
 	/**
@@ -538,7 +542,7 @@ class t3lib_positionMap {
 	 */
 	function getRecordHeader($row)	{
 		$line = t3lib_iconWorks::getIconImage('tt_content',$row,$this->backPath,' align="top" title="'.htmlspecialchars(t3lib_BEfunc::getRecordIconAltText($row,'tt_content')).'"');
-		$line.= t3lib_BEfunc::getRecordTitle('tt_content',$row,1);
+		$line.= t3lib_BEfunc::getRecordTitle('tt_content',$row,TRUE);
 		return $this->wrapRecordTitle($line,$row);
 	}
 
