@@ -3,7 +3,7 @@
 ########################################################################
 # Extension Manager/Repository config file for ext: "aboutmodules"
 #
-# Auto generated 23-04-2008 10:23
+# Auto generated 11-03-2009 19:04
 #
 # Manual updates:
 # Only the data in the array - anything else is removed by next write.
@@ -20,6 +20,7 @@ $EM_CONF[$_EXTKEY] = array(
 	'priority' => '',
 	'loadOrder' => '',
 	'module' => 'mod',
+	'doNotLoadInFE' => 1,
 	'state' => 'stable',
 	'internal' => 0,
 	'uploadfolder' => 0,
@@ -33,11 +34,11 @@ $EM_CONF[$_EXTKEY] = array(
 	'CGLcompliance' => '',
 	'CGLcompliance_note' => '',
 	'version' => '0.1.0',
-	'_md5_values_when_last_written' => 'a:5:{s:12:"ext_icon.gif";s:4:"24ff";s:14:"ext_tables.php";s:4:"3db6";s:20:"mod/aboutmodules.gif";s:4:"24ff";s:12:"mod/conf.php";s:4:"86ca";s:21:"mod/locallang_mod.xml";s:4:"8fa0";}',
+	'_md5_values_when_last_written' => 'a:5:{s:12:"ext_icon.gif";s:4:"24ff";s:14:"ext_tables.php";s:4:"b809";s:20:"mod/aboutmodules.gif";s:4:"24ff";s:12:"mod/conf.php";s:4:"86ca";s:21:"mod/locallang_mod.xml";s:4:"f533";}',
 	'constraints' => array(
 		'depends' => array(
 			'php' => '5.1.0-0.0.0',
-			'typo3' => '4.2.0-4.2.99',
+			'typo3' => '4.3.0-4.3.99',
 		),
 		'conflicts' => array(
 		),
