@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2008 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -107,19 +107,12 @@
  * 		external_ref[tables][]=table/_ALL
  */
 
-
-#unset($MCONF);
-#require ('conf.php');
-#require ($BACK_PATH.'init.php');
-#require ($BACK_PATH.'template.php');
+unset($MCONF);
+require ('conf.php');
+require_once ($BACK_PATH.'init.php');
+require_once ($BACK_PATH.'template.php');
 $LANG->includeLLFile('EXT:impexp/app/locallang.php');
-require_once (PATH_t3lib.'class.t3lib_scbase.php');
 require_once (t3lib_extMgm::extPath('impexp').'class.tx_impexp.php');
-require_once (PATH_t3lib.'class.t3lib_browsetree.php');
-require_once (PATH_t3lib.'class.t3lib_pagetree.php');
-
-require_once (PATH_t3lib.'class.t3lib_basicfilefunc.php');
-require_once (PATH_t3lib.'class.t3lib_extfilefunc.php');
 
 t3lib_extMgm::isLoaded('impexp',1);
 
@@ -290,10 +283,13 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 		global $BE_USER,$LANG,$BACK_PATH;
 
 			// Start document template object:
-		$this->doc = t3lib_div::makeInstance('mediumDoc');
+		$this->doc = t3lib_div::makeInstance('template');
 		$this->doc->backPath = $BACK_PATH;
-		$this->doc->docType = 'xhtml_trans';
 		$this->doc->bodyTagId = 'imp-exp-mod';
+		$this->doc->setModuleTemplate(t3lib_extMgm::extRelPath('impexp') . '/app/template.html');
+
+
+		$this->pageinfo = t3lib_BEfunc::readPageAccess($this->id, $this->perms_clause);
 
 				// JavaScript
 		$this->doc->JScode = $this->doc->wrapScriptTags('
@@ -306,13 +302,15 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 			// Set up JS for dynamic tab menu
 		$this->doc->JScode .= $this->doc->getDynTabMenuJScode();
 
+		// Setting up the context sensitive menu:
+		$this->doc->getContextMenuCode();
+
 		$this->doc->postCode = $this->doc->wrapScriptTags('
 			script_ended = 1;
 			if (top.fsMod) top.fsMod.recentIds["web"] = '.intval($this->id).';
 		');
 		$this->doc->form = '<form action="'.htmlspecialchars($GLOBALS['MCONF']['_']).'" method="post" enctype="'.$GLOBALS['TYPO3_CONF_VARS']['SYS']['form_enctype'].'"><input type="hidden" name="id" value="'.$this->id.'" />';
 
-		$this->content.= $this->doc->startPage($LANG->getLL('title'));
 		$this->content.= $this->doc->header($LANG->getLL('title'));
 		$this->content.= $this->doc->spacer(5);
 
@@ -347,9 +345,15 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 			break;
 		}
 
-		if ($BE_USER->mayMakeShortcut())	{
-			$this->content.=$this->doc->spacer(20).$this->doc->section('',$this->doc->makeShortcutIcon('tx_impexp','',$this->MCONF['name']));
-		}
+		// Setting up the buttons and markers for docheader
+		$docHeaderButtons = $this->getButtons();
+		$markers['CONTENT'] = $this->content;
+
+		// Build the <body> for the module
+		$this->content = $this->doc->startPage($LANG->getLL('title'));
+		$this->content.= $this->doc->moduleBody($this->pageinfo, $docHeaderButtons, $markers);
+		$this->content.= $this->doc->endPage();
+		$this->content = $this->doc->insertStylesAndJS($this->content);
 	}
 
 	/**
@@ -358,16 +362,48 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 	 * @return	void
 	 */
 	function printContent()	{
-
-		$this->content.= $this->doc->spacer(20);
-		$this->content.= $this->doc->endPage();
 		echo $this->content;
 	}
 
+	/**
+	 * Create the panel of buttons for submitting the form or otherwise perform operations.
+	 *
+	 * @return array all available buttons as an associated array
+	 */
+	protected function getButtons() {
+		$buttons = array(
+			'view' => '',
+			'record_list' => '',
+			'shortcut' => ''
+		);
 
+		if ($GLOBALS['BE_USER']->mayMakeShortcut()) {
+			$buttons['shortcut'] = $this->doc->makeShortcutIcon('tx_impexp', '', $this->MCONF['name']);
+		}
 
+		// Input data grabbed:
+		$inData = t3lib_div::_GP('tx_impexp');
+		if((string)$inData['action'] == 'import') {
+			if (($this->id && is_array($this->pageinfo)) || ($GLOBALS['BE_USER']->user['admin'] && !$this->id))	{
+				if (is_array($this->pageinfo) && $this->pageinfo['uid']) {
+					// View
+					$buttons['view'] = '<a href="#" onclick="' . htmlspecialchars(t3lib_BEfunc::viewOnClick($this->pageinfo['uid'], $this->doc->backPath, t3lib_BEfunc::BEgetRootLine($this->pageinfo['uid']))) . '">' .
+						'<img' . t3lib_iconWorks::skinImg($this->doc->backPath, 'gfx/zoom.gif') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.showPage', 1) . '" alt="" />' .
+						'</a>';
 
+					// Record list
+					if ($GLOBALS['BE_USER']->check('modules', 'web_list')) {
+						$href = $this->doc->backPath . 'db_list.php?id=' . $this->pageinfo['uid'] . '&returnUrl=' . rawurlencode(t3lib_div::getIndpEnv('REQUEST_URI'));
+						$buttons['record_list'] = '<a href="' . htmlspecialchars($href) . '">' .
+							'<img' . t3lib_iconWorks::skinImg($this->doc->backPath, 'gfx/list.gif') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.showList', 1) . '" alt="" />' .
+							'</a>';
+					}
+				}
+			}
+		}
 
+		return $buttons;
+	}
 
 
 
@@ -394,7 +430,7 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 		$inData['pagetree']['maxNumber'] = t3lib_div::intInRange($inData['pagetree']['maxNumber'],1,10000,100);
 		$inData['listCfg']['maxNumber'] = t3lib_div::intInRange($inData['listCfg']['maxNumber'],1,10000,100);
 		$inData['maxFileSize'] = t3lib_div::intInRange($inData['maxFileSize'],1,10000,1000);
-		$inData['filename'] = trim(ereg_replace('[^[:alnum:]./_-]*','',ereg_replace('\.(t3d|xml)$','',$inData['filename'])));
+		$inData['filename'] = trim(preg_replace('/[^[:alnum:]._-]*/','',preg_replace('/\.(t3d|xml)$/','',$inData['filename'])));
 		if (strlen($inData['filename']))	{
 			$inData['filename'].= $inData['filetype']=='xml' ? '.xml' : '.t3d';
 		}
@@ -420,7 +456,7 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 		$this->export->showStaticRelations = $inData['showStaticRelations'];
 
 		$this->export->includeExtFileResources = !$inData['excludeHTMLfileResources'];
-#debug($inData);
+
 			// Static tables:
 		if (is_array($inData['external_static']['tables']))	{
 			$this->export->relStaticTables = $inData['external_static']['tables'];
@@ -483,7 +519,6 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 				$this->treeHTML = $pagetree->printTree($tree);
 
 				$idH = $pagetree->buffer_idH;
-#				debug($pagetree->buffer_idH);
 			} elseif ($inData['pagetree']['levels']==-2)	{	// Only tables on page
 				$this->addRecordsForPid($inData['pagetree']['id'],$inData['pagetree']['tables'],$inData['pagetree']['maxNumber']);
 			} else {	// Based on depth
@@ -517,7 +552,6 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 
 					$pagetree = t3lib_div::makeInstance('localPageTree');
 					$this->treeHTML = $pagetree->printTree($tree->tree);
-#debug($idH);
 				}
 			}
 				// In any case we should have a multi-level array, $idH, with the page structure here (and the HTML-code loaded into memory for nice display...)
@@ -532,17 +566,15 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 		}
 
 			// After adding ALL records we set relations:
-#		debug($this->export->relOnlyTables);
-#		if (count($this->export->relOnlyTables))	{
-			for($a=0;$a<10;$a++)	{
-				$addR = $this->export->export_addDBRelations($a);
-				if (!count($addR)) break;
+		for($a=0;$a<10;$a++)	{
+			$addR = $this->export->export_addDBRelations($a);
+			if (!count($addR)) {
+				break;
 			}
-#		}
+		}
 
 			// Finally files are added:
 		$this->export->export_addFilesFromRelations();	// MUST be after the DBrelations are set so that files from ALL added records are included!
-#debug($this->export->dat['header']);
 			// If the download button is clicked, return file
 		if ($inData['download_export'] || $inData['save_export'])	{
 			switch((string)$inData['filetype'])	{
@@ -559,7 +591,7 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 			}
 
 				// Filename:
-			$dlFile = $inData['filename'] ? $inData['filename'] : 'T3D_'.substr(ereg_replace('[^[:alnum:]_]','-',$inData['download_export_name']),0,20).'_'.date('d-m-H-i-s').$fExt;
+			$dlFile = $inData['filename'] ? $inData['filename'] : 'T3D_'.substr(preg_replace('/[^[:alnum:]_]/','-',$inData['download_export_name']),0,20).'_'.date('d-m-H-i-s').$fExt;
 
 				// Export for download:
 			if ($inData['download_export'])	{
@@ -944,7 +976,7 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 		$presets = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
 						'*',
 						'tx_impexp_presets',
-						'(public>0 || user_uid='.intval($GLOBALS['BE_USER']->user['uid']).')'.
+						'(public>0 OR user_uid='.intval($GLOBALS['BE_USER']->user['uid']).')'.
 							($inData['pagetree']['id'] ? ' AND (item_uid='.intval($inData['pagetree']['id']).' OR item_uid=0)' : '')
 
 					);
@@ -1065,7 +1097,6 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 	function importData($inData)	{
 		global $TCA,$LANG,$BE_USER;
 
-		$this->pageinfo = t3lib_BEfunc::readPageAccess($this->id,$this->perms_clause);
 		$access = is_array($this->pageinfo) ? 1 : 0;
 
 		if (($this->id && $access) || ($BE_USER->user['admin'] && !$this->id))	{
@@ -1073,9 +1104,6 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 				$this->pageinfo=array('title' => '[root-level]','uid'=>0,'pid'=>0);
 			}
 
-			$headerSection = $this->doc->getHeader('pages',$this->pageinfo,$this->pageinfo['_thePath']).'<br />'.$LANG->sL('LLL:EXT:lang/locallang_core.php:labels.path').': '.t3lib_div::fixed_lgd_cs($this->pageinfo['_thePath'],-50);
-			$this->content.= $this->doc->section('',$headerSection);
-
 			if ($inData['new_import'])	{
 				unset($inData['import_mode']);
 			}
@@ -1098,10 +1126,10 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 			// Make input selector:
 			$path = $GLOBALS['TYPO3_CONF_VARS']['BE']['fileadminDir'];	// must have trailing slash.
 			$filesInDir = t3lib_div::getFilesInDir(PATH_site.$path, 't3d,xml', 1, 1);
-			
+
 			$userPath = $this->userSaveFolder(); //Files from User-Dir
 			$filesInUserDir = t3lib_div::getFilesInDir($userPath, 't3d,xml', 1, 1);
-			
+
 			$filesInDir = array_merge($filesInUserDir, $filesInDir);
 
 			if (is_dir(PATH_site.$path.'export/'))	{
@@ -1271,10 +1299,9 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 					if ($inData['import_file'])	{
 						if (!count($extKeysToInstall))	{
 							$import->importData($this->id);
-							t3lib_BEfunc::getSetUpdateSignal('updatePageTree');
+							t3lib_BEfunc::setUpdateSignal('updatePageTree');
 						} else {
-							header('Location: '.t3lib_div::locationHeaderUrl($emURL));
-							exit;
+							t3lib_utility_Http::redirect($emURL);
 						}
 					}
 
@@ -1564,7 +1591,7 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 			// Initializing:
 		$this->fileProcessor = t3lib_div::makeInstance('t3lib_extFileFunctions');
 		$this->fileProcessor->init($FILEMOUNTS, $TYPO3_CONF_VARS['BE']['fileExtensions']);
-		$this->fileProcessor->init_actionPerms($BE_USER->user['fileoper_perms']);
+		$this->fileProcessor->init_actionPerms($GLOBALS['BE_USER']->getFileoperationPermissions());
 		$this->fileProcessor->dontCheckForUnique = t3lib_div::_GP('overwriteExistingFiles') ? 1 : 0;
 
 			// Checking referer / executing:
@@ -1691,25 +1718,17 @@ class SC_mod_tools_log_index extends t3lib_SCbase {
 	}
 }
 
-// Include extension?
+
 if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/impexp/app/index.php'])	{
 	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/impexp/app/index.php']);
 }
 
 
 
-
-
-
-
-
-
-
-
-
 // Make instance:
 $SOBE = t3lib_div::makeInstance('SC_mod_tools_log_index');
 $SOBE->init();
 $SOBE->main();
 $SOBE->printContent();
-?>
+
+?>
\ No newline at end of file
