@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2008 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -28,13 +28,6 @@
  * @author	Kasper Skrhj <kasperYYYY@typo3.com>
  */
 
-require_once(PATH_t3lib."class.t3lib_tceforms.php");
-require_once(PATH_t3lib."class.t3lib_tcemain.php");
-
-require_once(PATH_t3lib."class.t3lib_fullsearch.php");
-require_once(PATH_t3lib."class.t3lib_xml.php");
-require_once(PATH_t3lib."class.t3lib_loaddbgroup.php");
-
 class tx_sysaction extends mod_user_task {
 	var $todoTypesCache = array();
 	var $insCounter=0;
@@ -78,7 +71,7 @@ class tx_sysaction extends mod_user_task {
 			if($actionRow = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res))	{
 
 					// Action header:
-				$header = t3lib_iconworks::getIconImage("sys_action",$actionRow,$this->backPath,'hspace="2" class="absmiddle"').'<b>'.$actionRow["title"].'</b>';
+				$header = t3lib_iconworks::getIconImage("sys_action",$actionRow,$this->backPath,'hspace="2" class="absmiddle"').'<b>'.htmlspecialchars($actionRow["title"]).'</b>';
 				$out.='<table border=0 cellpadding=0 cellspacing=1 width=100%>
 					<tr><td colspan=2 class="bgColor5">'.fw($header).'</td></tr>
 					<tr>
@@ -87,7 +80,7 @@ class tx_sysaction extends mod_user_task {
 					</tr>
 					<tr>
 						<td width=1% valign=top class="bgColor4">'.fw($LANG->sL(t3lib_BEfunc::getItemLabel("sys_action","description"))."&nbsp;").'</td>
-						<td valign=top class="bgColor4">'.fw(nl2br($actionRow["description"])).'</td>
+						<td valign=top class="bgColor4">'.fw(nl2br(htmlspecialchars($actionRow["description"]))).'</td>
 					</tr>';
 				$out.='</table>';
 				$theCode = $this->pObj->doc->section("",$out,0,1);
@@ -110,7 +103,7 @@ class tx_sysaction extends mod_user_task {
 								$userRecord=t3lib_BEfunc::getRecord("be_users",$nId);
 							}
 							if (t3lib_div::_GP("be_users_uid"))	{
-								$userRecord=t3lib_BEfunc::getRecord("be_users",t3lib_div::_GP("be_users_uid"));
+								$userRecord = t3lib_BEfunc::getRecord('be_users', t3lib_div::_GP('be_users_uid'), '*', ' AND cruser_id='.intval($this->BE_USER->user['uid']).' AND createdByAction='.intval($actionRow['uid']));
 							}
 							if (!is_array($userRecord))	{
 								$userRecord=array();
@@ -185,7 +178,7 @@ class tx_sysaction extends mod_user_task {
 								$actionContent="";
 	//		debug($sql_query);
 								$type = $sql_query["qC"]["search_query_makeQuery"];
-								$res = $GLOBALS['TYPO3_DB']->sql(TYPO3_db,$sql_query["qSelect"]);
+								$res = $GLOBALS['TYPO3_DB']->sql_query($sql_query["qSelect"]);
 								if (!$GLOBALS['TYPO3_DB']->sql_error())	{
 									$fullsearch->formW=48;
 									$cP=$fullsearch->getQueryResultCode($type,$res,$sql_query["qC"]["queryTable"]);
@@ -203,14 +196,18 @@ class tx_sysaction extends mod_user_task {
 										'&SET[search]=query'.
 										'&storeControl[STORE]=-'.$actionRow["uid"].
 										'&storeControl[LOAD]=1'.
-										'">Edit Query</a></strong>';
+										'">' . $GLOBALS['LANG']->getLL('action_editQuery') . '</a></strong>';
 								}
 								$theCode.= $this->pObj->doc->section($LANG->getLL("action_t2_result"),$actionContent,0,1);
 							} else {
 								$theCode.= $this->pObj->doc->section($LANG->getLL("action_error"),'<span class="typo3-red">'.$LANG->getLL("action_notReady").'</span>',0,1);
 							}
 						} else {
-							$theCode.= $this->pObj->doc->section($LANG->getLL("action_error"),'<span class="typo3-red">The extension "lowlevel" must be installed in order to create a quiry</span>',0,1);
+							$theCode.= $this->pObj->doc->section(
+								$GLOBALS['LANG']->getLL('action_error'),
+								'<span class="typo3-red">' . $GLOBALS['LANG']->getLL('action_lowlevelMissing', true) . '</span>',
+								0, 1
+							);
 						}
 					break;
 					case 3: //list records
@@ -278,7 +275,7 @@ class tx_sysaction extends mod_user_task {
 		$res = $this->getActionResPointer();
 		$lines=array();
 		while($actionRow = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res))	{
-			$lines[]='<nobr>'.t3lib_iconworks::getIconImage("sys_action",$actionRow,$this->backPath,'hspace="2" align="top"').$this->action_link($this->fixed_lgd($actionRow["title"]),$actionRow["uid"],$actionRow["description"]).'</nobr><BR>';
+			$lines[]='<nobr>'.t3lib_iconworks::getIconImage("sys_action",$actionRow,$this->backPath,'hspace="2" align="top"').$this->action_link($this->fixed_lgd(htmlspecialchars($actionRow['title'])),$actionRow['uid'],htmlspecialchars($actionRow['description'])).'</nobr><br />';
 		}
 		$out = implode("",$lines);
 		return $out;
@@ -365,7 +362,7 @@ class tx_sysaction extends mod_user_task {
 	function fixUsername($username,$prefix)	{
 		$username=trim($username);
 		$prefix=trim($prefix);
-		$username=ereg_replace("^".quotemeta($prefix),"",$username);
+		$username=preg_replace('/^'.quotemeta($prefix).'/','',$username);
 
 		if ($username)	{
 			return $prefix.$username;
@@ -417,4 +414,4 @@ if (defined("TYPO3_MODE") && $TYPO3_CONF_VARS[TYPO3_MODE]["XCLASS"]["ext/sys_act
 	include_once($TYPO3_CONF_VARS[TYPO3_MODE]["XCLASS"]["ext/sys_action/class.tx_sysaction.php"]);
 }
 
-?>
\ No newline at end of file
+?>
