@@ -1,13 +1,13 @@
 <?php
 
 ########################################################################
-# Extension Manager/Repository config file for ext: "version"
+# Extension Manager/Repository config file for ext "version".
 #
-# Auto generated 23-04-2008 10:26
+# Auto generated 21-10-2009 11:27
 #
 # Manual updates:
-# Only the data in the array - anything else is removed by next write.
-# "version" and "dependencies" must not be touched!
+# Only the data in the array - everything else is removed by next
+# writing. "version" and "dependencies" must not be touched!
 ########################################################################
 
 $EM_CONF[$_EXTKEY] = array(
@@ -21,6 +21,7 @@ $EM_CONF[$_EXTKEY] = array(
 	'conflicts' => '',
 	'priority' => '',
 	'module' => 'cm1',
+	'doNotLoadInFE' => 1,
 	'state' => 'beta',
 	'internal' => '',
 	'uploadfolder' => 0,
@@ -30,7 +31,7 @@ $EM_CONF[$_EXTKEY] = array(
 	'lockType' => '',
 	'author_company' => '',
 	'version' => '1.2.0',
-	'_md5_values_when_last_written' => 'a:8:{s:24:"class.tx_version_cm1.php";s:4:"e612";s:12:"ext_icon.gif";s:4:"1bdc";s:14:"ext_tables.php";s:4:"6e9e";s:13:"locallang.xml";s:4:"176c";s:13:"cm1/clear.gif";s:4:"cc11";s:15:"cm1/cm_icon.gif";s:4:"f35b";s:12:"cm1/conf.php";s:4:"6ed8";s:13:"cm1/index.php";s:4:"3f4a";}',
+	'_md5_values_when_last_written' => 'a:9:{s:24:"class.tx_version_cm1.php";s:4:"0bc1";s:12:"ext_icon.gif";s:4:"3ca2";s:14:"ext_tables.php";s:4:"46e8";s:13:"locallang.xml";s:4:"cc5e";s:7:"tca.php";s:4:"fbe7";s:13:"cm1/clear.gif";s:4:"cc11";s:15:"cm1/cm_icon.gif";s:4:"f35b";s:12:"cm1/conf.php";s:4:"6ed8";s:13:"cm1/index.php";s:4:"8921";}',
 	'constraints' => array(
 		'depends' => array(
 		),
