@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2008 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,7 +27,7 @@
 /**
  * Wizard to help make forms (fx. for tt_content elements) of type 'form'.
  *
- * $Id: wizard_forms.php 3439 2008-03-16 19:16:51Z flyguide $
+ * $Id: wizard_forms.php 6469 2009-11-17 23:56:35Z benni $
  * Revised for TYPO3 3.6 November/2003 by Kasper Skaarhoj
  * XHTML compliant
  *
@@ -206,8 +206,6 @@ class SC_wizard_forms {
 	 * @return	void
 	 */
 	function init()	{
-		global $BACK_PATH;
-
 			// GPvars:
 		$this->P = t3lib_div::_GP('P');
 		$this->special = t3lib_div::_GP('special');
@@ -217,9 +215,9 @@ class SC_wizard_forms {
 		$this->xmlStorage = $this->P['params']['xmlOutput'];
 
 			// Document template object:
-		$this->doc = t3lib_div::makeInstance('mediumDoc');
-		$this->doc->docType = 'xhtml_trans';
-		$this->doc->backPath = $BACK_PATH;
+		$this->doc = t3lib_div::makeInstance('template');
+		$this->doc->backPath = $GLOBALS['BACK_PATH'];
+		$this->doc->setModuleTemplate('templates/wizard_forms.html');
 		$this->doc->JScode=$this->doc->wrapScriptTags('
 			function jumpToUrl(URL,formEl)	{	//
 				window.location.href = URL;
@@ -230,9 +228,6 @@ class SC_wizard_forms {
 		list($rUri) = explode('#',t3lib_div::getIndpEnv('REQUEST_URI'));
 		$this->doc->form ='<form action="'.htmlspecialchars($rUri).'" method="post" name="wizardForm">';
 
-			// Start page:
-		$this->content=$this->doc->startPage('Form Wizard');
-
 			// If save command found, include tcemain:
 		if ($_POST['savedok_x'] || $_POST['saveandclosedok_x'])	{
 			$this->include_once[]=PATH_t3lib.'class.t3lib_tcemain.php';
@@ -245,13 +240,22 @@ class SC_wizard_forms {
 	 * @return	void
 	 */
 	function main()	{
-		global $LANG;
-
 		if ($this->P['table'] && $this->P['field'] && $this->P['uid'])	{
-			$this->content.=$this->doc->section($LANG->getLL('forms_title'),$this->formsWizard(),0,1);
+			$this->content .= $this->doc->section($GLOBALS['LANG']->getLL('forms_title'), $this->formsWizard(), 0, 1);
 		} else {
-			$this->content.=$this->doc->section($LANG->getLL('forms_title'),'<span class="typo3-red">'.$LANG->getLL('table_noData',1).'</span>',0,1);
+			$this->content .= $this->doc->section($GLOBALS['LANG']->getLL('forms_title'), '<span class="typo3-red">' . $GLOBALS['LANG']->getLL('table_noData',1) . '</span>', 0, 1);
 		}
+
+		// Setting up the buttons and markers for docheader
+		$docHeaderButtons = $this->getButtons();
+		$markers['CSH'] = $docHeaderButtons['csh'];
+		$markers['CONTENT'] = $this->content;
+
+		// Build the <body> for the module
+		$this->content = $this->doc->startPage('Form Wizard');
+		$this->content.= $this->doc->moduleBody($this->pageinfo, $docHeaderButtons, $markers);
+		$this->content.= $this->doc->endPage();
+		$this->content = $this->doc->insertStylesAndJS($this->content);
 	}
 
 	/**
@@ -260,11 +264,49 @@ class SC_wizard_forms {
 	 * @return	void
 	 */
 	function printContent()	{
-		$this->content.= $this->doc->endPage();
-		$this->content = $this->doc->insertStylesAndJS($this->content);
 		echo $this->content;
 	}
 
+	/**
+	 * Create the panel of buttons for submitting the form or otherwise perform operations.
+	 *
+	 * @return array all available buttons as an assoc. array
+	 */
+	protected function getButtons() {
+		$buttons = array(
+			'csh' => '',
+			'csh_buttons' => '',
+			'close' => '',
+			'save' => '',
+			'save_close' => '',
+			'reload' => '',
+		);
+
+		if ($this->P['table'] && $this->P['field'] && $this->P['uid']) {
+			// CSH
+			$buttons['csh'] = t3lib_BEfunc::cshItem('xMOD_csh_corebe', 'wizard_forms_wiz', $GLOBALS['BACK_PATH'], '');
+
+			// CSH Buttons
+			$buttons['csh_buttons'] = t3lib_BEfunc::cshItem('xMOD_csh_corebe', 'wizard_forms_wiz_buttons', $GLOBALS['BACK_PATH'], '');
+
+			// Close
+			$buttons['close'] = '<a href="#" onclick="' . htmlspecialchars('jumpToUrl(unescape(\'' . rawurlencode($this->P['returnUrl']) . '\')); return false;') . '">' .
+				'<img' . t3lib_iconWorks::skinImg($this->doc->backPath, 'gfx/closedok.gif') . ' class="c-inputButton" title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.closeDoc', 1) . '" alt="" />' .
+				'</a>';
+
+			// Save
+			$buttons['save'] = '<input type="image" class="c-inputButton" name="savedok"' . t3lib_iconWorks::skinImg($this->doc->backPath, 'gfx/savedok.gif') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveDoc', 1) . '" />';
+
+			// Save & Close
+			$buttons['save_close'] = '<input type="image" class="c-inputButton" name="saveandclosedok"' . t3lib_iconWorks::skinImg($this->doc->backPath, 'gfx/saveandclosedok.gif') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveCloseDoc', 1) . '" />';
+
+			// Reload
+			$buttons['reload'] = '<input type="image" class="c-inputButton" name="_refresh"' . t3lib_iconWorks::skinImg('', 'gfx/refresh_n.gif') . ' title="' . $GLOBALS['LANG']->getLL('forms_refresh', 1) . '" />';
+		}
+
+		return $buttons;
+	}
+
 	/**
 	 * Draws the form wizard content
 	 *
@@ -273,7 +315,7 @@ class SC_wizard_forms {
 	function formsWizard()	{
 
 			// First, check the references by selecting the record:
- 		$row = t3lib_BEfunc::getRecord($this->P['table'],$this->P['uid']);
+		$row = t3lib_BEfunc::getRecord($this->P['table'],$this->P['uid']);
 		if (!is_array($row))	{
 			t3lib_BEfunc::typo3PrintError ('Wizard Error','No reference to record',0);
 			exit;
@@ -358,9 +400,8 @@ class SC_wizard_forms {
 				$row = t3lib_BEfunc::getRecord($this->P['table'],$this->P['uid']);
 
 					// If the save/close button was pressed, then redirect the screen:
-				if ($_POST['saveandclosedok_x'])	{
-					header('Location: '.t3lib_div::locationHeaderUrl($this->P['returnUrl']));
-					exit;
+				if ($_POST['saveandclosedok_x']) {
+					t3lib_utility_Http::redirect($this->P['returnUrl']);
 				}
 			}
 		} else {	// If nothing has been submitted, load the $bodyText variable from the selected database row:
@@ -619,9 +660,6 @@ class SC_wizard_forms {
 
 		$content = '';
 
-			// Add CSH:
-		$content.= t3lib_BEfunc::cshItem('xMOD_csh_corebe', 'wizard_forms_wiz', $GLOBALS['BACK_PATH'],'');
-
 			// Implode all table rows into a string, wrapped in table tags.
 		$content.= '
 
@@ -632,25 +670,6 @@ class SC_wizard_forms {
 				'.implode('',$tRows).'
 			</table>';
 
-			// Add saving buttons in the bottom:
-		$content.= '
-
-			<!--
-				Save buttons:
-			-->
-			<div id="c-saveButtonPanel">';
-		$content.= '<input type="image" class="c-inputButton" name="savedok"'.t3lib_iconWorks::skinImg($this->doc->backPath,'gfx/savedok.gif','').' title="'.$LANG->sL('LLL:EXT:lang/locallang_core.php:rm.saveDoc',1).'" />';
-		$content.= '<input type="image" class="c-inputButton" name="saveandclosedok"'.t3lib_iconWorks::skinImg($this->doc->backPath,'gfx/saveandclosedok.gif','').' title="'.$LANG->sL('LLL:EXT:lang/locallang_core.php:rm.saveCloseDoc',1).'" />';
-		$content.= '<a href="#" onclick="'.htmlspecialchars('jumpToUrl(unescape(\''.rawurlencode($this->P['returnUrl']).'\')); return false;').'">'.
-					'<img'.t3lib_iconWorks::skinImg($this->doc->backPath,'gfx/closedok.gif','width="21" height="16"').' class="c-inputButton" title="'.$LANG->sL('LLL:EXT:lang/locallang_core.php:rm.closeDoc',1).'" alt="" />'.
-					'</a>';
-		$content.= '<input type="image" class="c-inputButton" name="_refresh"'.t3lib_iconWorks::skinImg('','gfx/refresh_n.gif','').' title="'.$LANG->getLL('forms_refresh',1).'" />';
-			// Add CSH:
-		$content.= t3lib_BEfunc::cshItem('xMOD_csh_corebe', 'wizard_forms_wiz_buttons', $GLOBALS['BACK_PATH'],'');
-		$content.= '
-			</div>
-		';
-
 			// Add hidden fields:
 		$content.= implode('',$hiddenFields);
 
@@ -791,7 +810,7 @@ class SC_wizard_forms {
 				}
 
 					// Compile the final line:
-				$inLines[]=ereg_replace("[\n\r]*",'',implode(' | ',$thisLine));
+				$inLines[]=preg_replace("/[\n\r]*/",'',implode(' | ',$thisLine));
 			}
 		}
 			// Finally, implode the lines into a string, and return it:
@@ -837,7 +856,7 @@ class SC_wizard_forms {
 
 				if ($confData['type'])	{
 					if (count($typeParts)==1)	{
-						$confData['fieldname'] = substr(ereg_replace('[^a-zA-Z0-9_]','',str_replace(' ','_',trim($parts[0]))),0,30);
+						$confData['fieldname'] = substr(preg_replace('/[^a-zA-Z0-9_]/','',str_replace(' ','_',trim($parts[0]))),0,30);
 
 							// Attachment names...
 						if ($confData['type']=='file')	{
@@ -949,22 +968,13 @@ class SC_wizard_forms {
 	}
 }
 
-// Include extension?
+
 if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['typo3/wizard_forms.php'])	{
 	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['typo3/wizard_forms.php']);
 }
 
 
 
-
-
-
-
-
-
-
-
-
 // Make instance:
 $SOBE = t3lib_div::makeInstance('SC_wizard_forms');
 $SOBE->init();
@@ -974,4 +984,5 @@ foreach($SOBE->include_once as $INC_FILE)	include_once($INC_FILE);
 
 $SOBE->main();
 $SOBE->printContent();
-?>
+
+?>
\ No newline at end of file
